@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2015 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ class SOLARUS_API SolarusFatal : public std::exception {
 
   public:
 
-    SolarusFatal(const std::string& error_message);
+    explicit SolarusFatal(const std::string& error_message);
     virtual const char* what() const noexcept override;
 
   private:
