@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2015 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,8 @@
 #define SOLARUS_DESTINATION_H
 
 #include "solarus/Common.h"
-#include "solarus/entities/MapEntity.h"
+#include "solarus/entities/Entity.h"
+#include "solarus/entities/StartingLocationMode.h"
 #include <string>
 
 namespace Solarus {
@@ -26,13 +27,15 @@ namespace Solarus {
 /**
  * \brief A location of the map where the hero can arrive when using a teletransporter.
  */
-class Destination: public MapEntity {
+class Destination: public Entity {
 
   public:
 
+    static constexpr EntityType ThisType = EntityType::DESTINATION;
+
     Destination(
         const std::string& name,
-        Layer layer,
+        int layer,
         const Point& xy,
         int hero_direction,
         const std::string& sprite_name,
@@ -40,12 +43,17 @@ class Destination: public MapEntity {
     );
 
     virtual EntityType get_type() const override;
-    virtual bool can_be_obstacle() const override;
     bool is_default() const;
 
+    StartingLocationMode get_starting_location_mode() const;
+    void set_starting_location_mode(StartingLocationMode mode);
+
   private:
 
-    bool is_default_destination;
+    StartingLocationMode starting_location_mode;  /**< Whether this destination updates
+                                                   * the starting location. */
+    bool is_default_destination;                  /**< Whether this is the default
+                                                   * destination of the map. */
 
 };
 
